export interface ActivationLog {
    /**
     * Activation ID
     * @format GUID
     */
    _id?: string;
    /**
     * The activated automation ID
     * @format GUID
     */
    automationId?: string;
    /** The activated automation revision */
    automationRevision?: string;
    /** Automation activation status */
    status?: Status;
    /** Scheduled status additional info */
    initiatedInfo?: InitiatedStatusInfo;
    /** Scheduled status additional info */
    scheduledInfo?: ScheduledStatusInfo;
    /** Started status additional info */
    startedInfo?: StartedStatusInfo;
    /** Ended status additional info */
    endedInfo?: EndedStatusInfo;
    /** Cancelled status additional info */
    cancelledInfo?: CancelledStatusInfo;
    /** Failed status additional info */
    failedInfo?: FailedStatusInfo;
    /** Skipped status additional info */
    skippedInfo?: SkippedStatusInfo;
    /**
     * Warnings information
     * @maxSize 15
     */
    warnings?: Warning[];
    /** Created date */
    _createdDate?: Date | null;
}
export declare enum Target {
    UNKNOWN_TARGET = "UNKNOWN_TARGET",
    SCHEDULE = "SCHEDULE",
    IMMEDIATE = "IMMEDIATE"
}
export declare enum CancellationReason {
    UNKNOWN_CANCELLATION_REASON = "UNKNOWN_CANCELLATION_REASON",
    /** Indicating that the activation was cancelled directly */
    EVENT_CANCELLED = "EVENT_CANCELLED",
    /** Indicating that the activation is cancelled because the automation was deactivated */
    AUTOMATION_DEACTIVATED = "AUTOMATION_DEACTIVATED",
    /** Indicating that the activation is cancelled because the automation was deleted */
    AUTOMATION_DELETED = "AUTOMATION_DELETED",
    /** Indicating that the activation is cancelled after the automation schedule time was reached */
    CANCELLED_BY_REFRESH_PAYLOAD = "CANCELLED_BY_REFRESH_PAYLOAD",
    /** Indicates that the activation was cancelled due to a UoU GDPR "Right to be Forgotten" request. */
    CANCELLED_BY_GDPR_REQUEST = "CANCELLED_BY_GDPR_REQUEST"
}
export interface Identity {
    /**
     * User ID
     * @format GUID
     */
    userId?: string | null;
    /**
     * App ID
     * @format GUID
     */
    appId?: string | null;
}
export declare enum ErrorReason {
    /** Unexpected error reason */
    UNEXPECTED_ERROR_REASON = "UNEXPECTED_ERROR_REASON",
    /** Failed to evaluate the schedule date expression */
    SCHEDULE_DATE_EVALUATION_FAILED = "SCHEDULE_DATE_EVALUATION_FAILED"
}
export declare enum SkipReason {
    UNKNOWN_SKIP_REASON = "UNKNOWN_SKIP_REASON",
    /** Activation was skipped because the scheduled execution time had already passed at the time of execution */
    SCHEDULE_DATE_EXPIRED = "SCHEDULE_DATE_EXPIRED",
    /** Activation was skipped because the trigger filters defined in the automation did not match the payload. */
    TRIGGER_FILTERS_NOT_PASSED = "TRIGGER_FILTERS_NOT_PASSED",
    /** Activation was skipped because it exceeded the configured rate limit (maximum number of executions allowed in a time period). */
    RATE_LIMIT_EXCEEDED = "RATE_LIMIT_EXCEEDED",
    /** Activation was skipped because an event with the same idempotency key was already processed. */
    EVENT_ALREADY_PROCESSED = "EVENT_ALREADY_PROCESSED"
}
export declare enum Status {
    UNKNOWN_STATUS = "UNKNOWN_STATUS",
    /** This indicates activation is not started yet (no action has run yet) */
    INITIATED = "INITIATED",
    /** The activation is in scheduled status when the automation has future date or debounce defined and we're in the waiting stage (no action has run yet) */
    SCHEDULED = "SCHEDULED",
    /** This indicates the automation activation has started and currently in progress */
    STARTED = "STARTED",
    /** This indicates all the automation actions were handled either by invoking them, skipping them etc. */
    ENDED = "ENDED",
    /** This indicates the activation was cancelled */
    CANCELLED = "CANCELLED",
    /**
     * This indicates the activation failed to start
     * Note that failure in the activation of a single action will not result a failure in activation of the entire automation
     */
    FAILED = "FAILED",
    /**
     * Indicates that the automation activation was skipped without executing any actions.
     * Note that an activation will either be skipped immediately or move to INITIATED state.
     */
    SKIPPED = "SKIPPED"
}
export interface InitiatedStatusInfo {
    /** Created date */
    statusChangedDate?: Date | null;
    /** Target */
    target?: Target;
    /** The reported trigger payload */
    payload?: Record<string, any> | null;
    /**
     * External entity ID
     * @maxLength 40
     */
    externalEntityId?: string | null;
    /**
     * Unique identifier for the request that initiated the automation
     * @maxLength 100
     */
    requestId?: string | null;
}
export interface ScheduledStatusInfo {
    /** Created date */
    statusChangedDate?: Date | null;
    /**
     * Schedule identifier
     * @format GUID
     */
    scheduleId?: string;
    /** Indicating when the activation should start */
    date?: Date | null;
}
export interface StartedStatusInfo {
    /** Created date */
    statusChangedDate?: Date | null;
    /** Enriched and refreshed payload */
    payload?: Record<string, any> | null;
}
export interface EndedStatusInfo {
    /** Created date */
    statusChangedDate?: Date | null;
    /** Indicates if the activation failed with errors in one or more actions. Actions that failed but eventually ended are not included */
    withFailedActions?: boolean | null;
}
export interface CancelledStatusInfo {
    /** Created date */
    statusChangedDate?: Date | null;
    /** Cancellation reason */
    reason?: CancellationReason;
    /** The identity (such as user, app etc.) that caused the cancellation */
    initiator?: Identity;
}
export interface FailedStatusInfo {
    /** Created date */
    statusChangedDate?: Date | null;
    /**
     * Error description
     * @maxLength 1000
     * @readonly
     */
    errorDescription?: string;
    /**
     * Error code
     * @maxLength 20
     */
    errorCode?: string | null;
    /** Error reason */
    errorReason?: ErrorReason;
    /** Event payload */
    payload?: Record<string, any> | null;
    /**
     * External entity ID
     * @maxLength 40
     */
    externalEntityId?: string | null;
    /**
     * Unique identifier for the request that initiated the automation
     * @maxLength 100
     */
    requestId?: string | null;
}
export interface SkippedStatusInfo {
    /** Created date */
    statusChangedDate?: Date | null;
    /** The reason why the automation activation was skipped */
    reason?: SkipReason;
    /** The reported trigger payload */
    payload?: Record<string, any> | null;
    /**
     * External entity ID
     * @maxLength 40
     */
    externalEntityId?: string | null;
    /**
     * Unique identifier for the request that initiated the automation
     * @maxLength 100
     */
    requestId?: string | null;
}
export interface Warning {
    /** Event date */
    warningDate?: Date | null;
    /**
     * Detailed description of what caused the warning
     * @maxLength 1000
     * @readonly
     */
    errorDescription?: string;
    /**
     * Error code of what caused the warning
     * @maxLength 20
     * @readonly
     */
    errorCode?: string | null;
    /** The reason for the warning */
    reason?: WarningReason;
}
export declare enum WarningReason {
    UNKNOWN_WARNING_REASON = "UNKNOWN_WARNING_REASON",
    /** Failed to enrich payload with studio site enrichment */
    STUDIO_SITE_ENRICHMENT_FAILED = "STUDIO_SITE_ENRICHMENT_FAILED",
    /** Failed to refresh payload data */
    REFRESH_PAYLOAD_FAILED = "REFRESH_PAYLOAD_FAILED",
    /** Failed to retrieve contact information */
    GET_CONTACT_ENRICHMENT_FAILED = "GET_CONTACT_ENRICHMENT_FAILED",
    /** Failed to retrieve member information */
    GET_MEMBER_ENRICHMENT_FAILED = "GET_MEMBER_ENRICHMENT_FAILED"
}
export interface DomainEvent extends DomainEventBodyOneOf {
    createdEvent?: EntityCreatedEvent;
    updatedEvent?: EntityUpdatedEvent;
    deletedEvent?: EntityDeletedEvent;
    actionEvent?: ActionEvent;
    /**
     * Unique event ID.
     * Allows clients to ignore duplicate webhooks.
     */
    _id?: string;
    /**
     * Assumes actions are also always typed to an entity_type
     * Example: wix.stores.catalog.product, wix.bookings.session, wix.payments.transaction
     */
    entityFqdn?: string;
    /**
     * This is top level to ease client code dispatching of messages (switch on entity_fqdn+slug)
     * This is although the created/updated/deleted notion is duplication of the oneof types
     * Example: created/updated/deleted/started/completed/email_opened
     */
    slug?: string;
    /** ID of the entity associated with the event. */
    entityId?: string;
    /** Event timestamp in [ISO-8601](https://en.wikipedia.org/wiki/ISO_8601) format and UTC time. For example: 2020-04-26T13:57:50.699Z */
    eventTime?: Date | null;
    /**
     * Whether the event was triggered as a result of a privacy regulation application
     * (for example, GDPR).
     */
    triggeredByAnonymizeRequest?: boolean | null;
    /** If present, indicates the action that triggered the event. */
    originatedFrom?: string | null;
    /**
     * A sequence number defining the order of updates to the underlying entity.
     * For example, given that some entity was updated at 16:00 and than again at 16:01,
     * it is guaranteed that the sequence number of the second update is strictly higher than the first.
     * As the consumer, you can use this value to ensure that you handle messages in the correct order.
     * To do so, you will need to persist this number on your end, and compare the sequence number from the
     * message against the one you have stored. Given that the stored number is higher, you should ignore the message.
     */
    entityEventSequence?: string | null;
}
/** @oneof */
export interface DomainEventBodyOneOf {
    createdEvent?: EntityCreatedEvent;
    updatedEvent?: EntityUpdatedEvent;
    deletedEvent?: EntityDeletedEvent;
    actionEvent?: ActionEvent;
}
export interface EntityCreatedEvent {
    entity?: string;
}
export interface RestoreInfo {
    deletedDate?: Date | null;
}
export interface EntityUpdatedEvent {
    /**
     * Since platformized APIs only expose PATCH and not PUT we can't assume that the fields sent from the client are the actual diff.
     * This means that to generate a list of changed fields (as opposed to sent fields) one needs to traverse both objects.
     * We don't want to impose this on all developers and so we leave this traversal to the notification recipients which need it.
     */
    currentEntity?: string;
}
export interface EntityDeletedEvent {
    /** Entity that was deleted */
    deletedEntity?: string | null;
}
export interface ActionEvent {
    body?: string;
}
export interface Empty {
}
export interface ActivationContinuedAfterSchedule {
    /**
     * Activation identifier
     * @format GUID
     */
    _id?: string;
    /** Activation Automation */
    automation?: Automation;
}
export interface Automation extends AutomationOriginInfoOneOf {
    /** Application info */
    applicationInfo?: ApplicationOrigin;
    /** Preinstalled info */
    preinstalledInfo?: PreinstalledOrigin;
    /**
     * Automation ID.
     * @format GUID
     * @readonly
     */
    _id?: string | null;
    /**
     * Revision number, which increments by 1 each time the automation is updated.
     * To prevent conflicting changes,
     * the current revision must be passed when updating the automation.
     *
     * Ignored when creating an automation.
     * @readonly
     */
    revision?: string | null;
    /**
     * Information about the creator of the automation.
     * @immutable
     * @readonly
     */
    createdBy?: AuditInfo;
    /**
     * Date and time the automation was created.
     * @readonly
     */
    _createdDate?: Date | null;
    /**
     * The entity that last updated the automation.
     * @readonly
     */
    updatedBy?: AuditInfo;
    /**
     * Date and time the automation was last updated.
     * @readonly
     */
    _updatedDate?: Date | null;
    /**
     * Automation name that is displayed on the user's site.
     * @minLength 1
     * @maxLength 500
     */
    name?: string;
    /**
     * Automation description.
     * @maxLength 2000
     */
    description?: string | null;
    /** Object that defines the automation's trigger, actions, and activation status. */
    configuration?: AutomationConfiguration;
    /**
     * Defines how the automation was added to the site.
     * @immutable
     */
    origin?: Origin;
    /** Automation settings. */
    settings?: AutomationSettings;
    /**
     * Draft info (optional - only if the automation is a draft)
     * @readonly
     */
    draftInfo?: DraftInfo;
    /**
     * Namespace
     * @maxLength 50
     */
    namespace?: string | null;
    /** Extended Fields */
    extendedFields?: ExtendedFields;
}
/** @oneof */
export interface AutomationOriginInfoOneOf {
    /** Application info */
    applicationInfo?: ApplicationOrigin;
    /** Preinstalled info */
    preinstalledInfo?: PreinstalledOrigin;
}
export interface ActionSettings {
    /**
     * List of actions that cannot be deleted.
     * Default: Empty. All actions are deletable by default.
     * @maxSize 30
     * @format GUID
     */
    permanentActionIds?: string[];
    /**
     * List of actions that cannot be edited.
     * Default: Empty. All actions are editable by default.
     * @maxSize 30
     * @format GUID
     */
    readonlyActionIds?: string[];
    /** Whether the option to add a delay is disabled for the automation. */
    disableDelayAddition?: boolean;
    /** Whether the option to add a condition is disabled for the automation. */
    disableConditionAddition?: boolean;
}
export declare enum Domain {
    /** User domain (default). */
    USER = "USER",
    /** Wix domain. */
    WIX = "WIX"
}
export interface Enrichment {
    /**
     * Enrichment input mappings.
     * @maxSize 2
     */
    inputMappings?: Record<string, any>[] | null;
}
export interface AuditInfo extends AuditInfoIdOneOf {
    /**
     * User ID.
     * @format GUID
     */
    userId?: string;
    /**
     * Application ID.
     * @format GUID
     */
    appId?: string;
}
/** @oneof */
export interface AuditInfoIdOneOf {
    /**
     * User ID.
     * @format GUID
     */
    userId?: string;
    /**
     * Application ID.
     * @format GUID
     */
    appId?: string;
}
/** Automation runtime configuration */
export interface AutomationConfiguration {
    /** Status of the automation on the site. */
    status?: AutomationConfigurationStatus;
    /** Automation trigger configuration. */
    trigger?: Trigger;
    /**
     * List of IDs of root actions. Root actions are the first actions to run after the trigger. The actions in the list run in parallel.
     * @maxSize 20
     * @format GUID
     */
    rootActionIds?: string[];
    /**
     * Map of all actions that the automation may execute.
     * The key is the action ID, and the value is the action configuration.
     */
    actions?: Record<string, Action>;
}
export declare enum TimeUnit {
    UNKNOWN_TIME_UNIT = "UNKNOWN_TIME_UNIT",
    MINUTES = "MINUTES",
    HOURS = "HOURS",
    DAYS = "DAYS",
    WEEKS = "WEEKS",
    MONTHS = "MONTHS"
}
export interface Filter {
    /**
     * Filter ID.
     * @format GUID
     */
    _id?: string;
    /**
     * Field key from the payload schema, for example "formId".
     * @minLength 1
     * @maxLength 110
     */
    fieldKey?: string;
    /**
     * Filter expression that evaluates to a boolean.
     * @maxLength 2500
     */
    filterExpression?: string;
}
export interface FutureDateActivationOffset {
    /**
     * The offset value. The value is always taken as negative, so that the automation runs before the trigger date.
     * To create an offset that causes the automation to run after the trigger date, use a delay action.
     * @maxLength 1000
     */
    preScheduledEventOffsetExpression?: string;
    /** Time unit for the scheduled event offset. */
    scheduledEventOffsetTimeUnit?: TimeUnit;
}
export interface RateLimit {
    /**
     * Value expressing the maximum number of times the trigger can be activated.
     * @maxLength 1000
     */
    maxActivationsExpression?: string;
    /**
     * Duration of the rate limiting window in the selected time unit. If no value is set, the rate limit is permanent.
     * @maxLength 1000
     */
    durationExpression?: string | null;
    /** Time unit for the rate limit duration. */
    durationTimeUnit?: TimeUnit;
    /**
     * Unique identifier of each activation, by which rate limiter will count activations.
     * @minLength 1
     * @maxLength 400
     */
    uniqueIdentifierExpression?: string | null;
}
export interface FilterValueSelection {
    /**
     * Values that can help the user filter certain automations, values will look like "<filter_id>__<selected_value>"
     * @maxLength 80
     * @maxSize 50
     */
    selectedFilterValues?: string[];
}
export interface ConditionExpressionGroup {
    /** Expression group operator. */
    operator?: Operator;
    /**
     * List of boolean expressions to be evaluated with the given operator.
     * @minSize 1
     * @maxSize 20
     * @maxLength 2500
     */
    booleanExpressions?: string[];
}
export declare enum Operator {
    UNKNOWN_OPERATOR = "UNKNOWN_OPERATOR",
    OR = "OR",
    AND = "AND"
}
export declare enum Type {
    /** Automation will be triggered according to the trigger configuration. */
    UNKNOWN_ACTION_TYPE = "UNKNOWN_ACTION_TYPE",
    /** App defined Action. */
    APP_DEFINED = "APP_DEFINED",
    /** Condition Action. */
    CONDITION = "CONDITION",
    /** Delay Action. */
    DELAY = "DELAY",
    /** RateLimit Action. */
    RATE_LIMIT = "RATE_LIMIT",
    /** Set Variables Action. */
    SET_VARIABLES = "SET_VARIABLES",
    /** Output Action. */
    OUTPUT = "OUTPUT"
}
export interface AppDefinedAction {
    /**
     * ID of the app that defines the action.
     * @format GUID
     */
    appId?: string;
    /**
     * Action key.
     * @minLength 1
     * @maxLength 100
     */
    actionKey?: string;
    /** Action input mapping. */
    inputMapping?: Record<string, any> | null;
    /**
     * Array of conditions determining whether to skip the action in the automation flow.
     * The action will be skipped if any of the expression groups evaluate to `true`.
     * Actions following a skipped action will still run.
     * @maxSize 10
     */
    skipConditionOrExpressionGroups?: ConditionExpressionGroup[];
    /**
     * List of IDs of actions to run in parallel once the action completes.
     * @maxSize 20
     * @format GUID
     */
    postActionIds?: string[];
    /** Optional output schema of the action. It will be used instead the action schema in case it's provided. */
    overrideOutputSchema?: Record<string, any> | null;
}
export interface ConditionAction {
    /**
     * The condition evaluates to `true` if either of the expression groups evaluate to `true`.
     * @minSize 1
     * @maxSize 10
     */
    orExpressionGroups?: ConditionExpressionGroup[];
    /**
     * List of IDs of actions to run when the entire condition is evaluated to `true`.
     * @maxSize 20
     * @format GUID
     */
    truePostActionIds?: string[];
    /**
     * List of IDs of actions to run when the entire condition is evaluated to `false`.
     * @maxSize 20
     * @format GUID
     */
    falsePostActionIds?: string[];
}
export interface DelayAction {
    /**
     * Value expressing the amount of time to wait from a specific date or from the time the action is executed.
     * @maxLength 1000
     */
    offsetExpression?: string | null;
    /** Time unit for delay offset. */
    offsetTimeUnit?: TimeUnit;
    /**
     * The action due date. If defined without an offset, the automation will wait until this date to execute the next step.
     * If an offset is defined, it's calculated from this date.
     * The date is expressed in the number of milliseconds since the Unix Epoch (1 January, 1970 UTC).
     * @maxLength 1000
     */
    dueDateEpochExpression?: string | null;
    /**
     * List of IDs of actions to run in parallel after the delay.
     * @maxSize 20
     * @format GUID
     */
    postActionIds?: string[];
}
export interface RateLimitAction {
    /**
     * The maximum number of activations allowed for the action.
     * @maxLength 1000
     */
    maxActivationsExpression?: string;
    /**
     * Duration of the rate limiting window, expressed in selected time unit.
     * If no value is set, then there is no time limit on the rate limiter.
     * @maxLength 1000
     */
    rateLimitDurationExpression?: string | null;
    /** Time unit for the rate limit duration. */
    rateLimitDurationTimeUnit?: TimeUnit;
    /**
     * Unique identifier of each activation by which rate limiter counts activations.
     * @minLength 1
     * @maxLength 400
     */
    uniqueIdentifierExpression?: string | null;
    /**
     * List of IDs of actions to run in parallel once the action completes.
     * @maxSize 20
     * @format GUID
     */
    postActionIds?: string[];
}
export interface SetVariablesAction {
    /**
     * output mapping
     * for example: {"someField": "{{10}}", "someOtherField": "{{multiply( var('account.points.balance') ;2 )}}" }
     */
    outputMapping?: Record<string, any> | null;
    /**
     * output json schema representation
     * could be string instead of Struct (and introduce some compression to minimize the size of it)
     */
    outputSchema?: Record<string, any> | null;
    /**
     * List of IDs of actions to run in parallel after variable initialization.
     * @maxSize 20
     * @format GUID
     */
    postActionIds?: string[];
}
export interface OutputAction {
    /** Output action output mapping. */
    outputMapping?: Record<string, any> | null;
}
export declare enum AutomationConfigurationStatus {
    /** unused */
    UNKNOWN_STATUS = "UNKNOWN_STATUS",
    /** Automation will be triggered according to the trigger configuration */
    ACTIVE = "ACTIVE",
    /** Automation will not be triggered */
    INACTIVE = "INACTIVE"
}
export interface Trigger {
    /**
     * ID of the app that defines the trigger.
     * @format GUID
     */
    appId?: string;
    /**
     * Trigger key.
     * @minLength 1
     * @maxLength 100
     */
    triggerKey?: string;
    /**
     * List of filters on schema fields.
     * In order for the automation to run, all filter expressions must evaluate to `true` for a given payload.
     * @maxSize 5
     */
    filters?: Filter[];
    /** Defines the time offset between the trigger date and when the automation runs. */
    scheduledEventOffset?: FutureDateActivationOffset;
    /** Limits the number of times an automation can be triggered. */
    rateLimit?: RateLimit;
    /**
     * An optional configuration, per automation, of a schema that is optionally offered by the trigger provider to affect the behavior of the trigger.
     * For example, a trigger provider may offer a schema that allows the user to configure the trigger to happen at a certain time of day,
     * He would define a schema with a field called "startDate" and using this parameter the user can define his preferred startDate, per automation.
     */
    automationConfigMapping?: Record<string, any> | null;
    /** Optional schema of the trigger. It will be used instead the trigger schema in case it's provided. */
    overrideSchema?: Record<string, any> | null;
}
export interface Action extends ActionInfoOneOf {
    /** Action defined by an app (via RPC, HTTP or Velo). */
    appDefinedInfo?: AppDefinedAction;
    /** Condition action. */
    conditionInfo?: ConditionAction;
    /** Delay action. */
    delayInfo?: DelayAction;
    /** Rate-limiting action. */
    rateLimitInfo?: RateLimitAction;
    /**
     * Action ID. If not specified, a new ID is generated.
     * @format GUID
     */
    _id?: string | null;
    /** Action type. */
    type?: Type;
    /**
     * Human-readable name to differentiate the action from other actions of the same type.
     * The name can contain only alphanumeric characters and underscores. If not provided, a namespace in the form `actionkey-indexOfAction` is
     * generated automatically.
     * If the action has output, the output will be available in the payload under this name.
     * If the user has multiple actions with the same appId and actionKey, previous action output will be overwritten.
     * @minLength 1
     * @maxLength 100
     */
    namespace?: string | null;
}
/** @oneof */
export interface ActionInfoOneOf {
    /** Action defined by an app (via RPC, HTTP or Velo). */
    appDefinedInfo?: AppDefinedAction;
    /** Condition action. */
    conditionInfo?: ConditionAction;
    /** Delay action. */
    delayInfo?: DelayAction;
    /** Rate-limiting action. */
    rateLimitInfo?: RateLimitAction;
}
export interface FilterableAppDefinedActions {
    /**
     * App defined action identifiers, each identifier in form `${appId}_${actionKey}`
     * @minSize 1
     * @maxSize 100
     * @minLength 1
     * @maxLength 150
     */
    actionIdentifiers?: string[];
}
export declare enum Origin {
    /** Default value. This is unused. */
    UNKNOWN_ORIGIN = "UNKNOWN_ORIGIN",
    /** User created automation. */
    USER = "USER",
    /** Automation created by application (site specific). */
    APPLICATION = "APPLICATION",
    /** Preinstalled application automation. */
    PREINSTALLED = "PREINSTALLED",
    /** Automation created from a recipe. */
    RECIPE = "RECIPE"
}
export interface ApplicationOrigin {
    /**
     * Application ID.
     * @format GUID
     */
    appId?: string;
    /**
     * External ID to correlate multiple sites to an automation
     * @format GUID
     */
    appDefinedExternalId?: string | null;
}
export interface PreinstalledOrigin {
    /**
     * ID of the app that defines the preinstalled automation.
     * @format GUID
     */
    appId?: string;
    /**
     * Application component ID.
     * @format GUID
     */
    componentId?: string;
    /** Application component version. */
    componentVersion?: number;
    /**
     * Whether the automation is an override automation. If the user modifies the preinstalled automation installed on their site, a site-specific
     * automation is created that overrides the original one. If the user makes no modifications this boolean is set to `false` and the original
     * preinstalled automation is used.
     *
     * Default: `false`
     * @immutable
     * @readonly
     */
    override?: boolean | null;
}
export interface AutomationSettings {
    /**
     * Whether the automation is hidden from users.
     * Default: `false`
     */
    hidden?: boolean;
    /**
     * Whether the automation is read-only.
     * Default: `false`
     */
    readonly?: boolean;
    /**
     * Whether the option to delete the automation from the site is disabled.
     * Default: `false`
     */
    disableDelete?: boolean;
    /**
     * Whether the option to change the automation status (from active to inactive and vice versa) is disabled.
     * Default: `false`
     */
    disableStatusChange?: boolean;
    /** Automation action settings. */
    actionSettings?: ActionSettings;
}
export interface DraftInfo {
    /**
     * Optional - automationId of the original automation.
     * @format GUID
     * @readonly
     */
    originalAutomationId?: string | null;
}
export interface Enrichments {
    /** Whether the studio site enrichment is wanted. */
    studioSite?: Enrichment;
}
export interface ExtendedFields {
    /**
     * Extended field data. Each key corresponds to the namespace of the app that created the extended fields.
     * The value of each key is structured according to the schema defined when the extended fields were configured.
     *
     * You can only access fields for which you have the appropriate permissions.
     *
     * Learn more about [extended fields](https://dev.wix.com/docs/rest/articles/getting-started/extended-fields).
     */
    namespaces?: Record<string, Record<string, any>>;
}
export interface UouDeleteRequest {
    /** Original UouRightToBeDeletedRequest request */
    originalRequest?: Record<string, any> | null;
    /**
     * Found client ids
     * @maxSize 100
     */
    foundClientEntityIdsByNamespace?: ClientEntityIdsByNamespace[];
}
export interface ClientEntityIdsByNamespace {
    /**
     * Client namespace
     * @minLength 5
     * @maxLength 50
     */
    namespace?: string;
    /**
     * Client entity IDs
     * @minLength 5
     * @maxLength 50
     * @maxSize 100
     */
    clientEntityIds?: string[];
}
export interface GetActivationLogRequest {
    /**
     * Activation log ID
     * @format GUID
     */
    activationId: string;
}
export interface GetActivationLogResponse {
    /** Activation log */
    activationLog?: ActivationLog;
}
export interface ListActivationLogsRequest extends ListActivationLogsRequestIdentifierOneOf {
    /** Look up activations by automation id */
    automationIdInfo?: AutomationIdInfo;
    /** Look up activations by preinstalled identifier */
    preinstalledIdentifierInfo?: PreinstalledIdentifierInfo;
    /** From created date, If not specified, defaults to 30 days before the current time. */
    fromCreatedDate?: Date | null;
    /** To created date, If not specified, defaults to current time. */
    toCreatedDate?: Date | null;
    /** Paging */
    cursorPaging?: CursorPaging;
    /** Should return payload in the response */
    includePayload?: boolean | null;
    /** identifier type for the activations to list */
    identifierType?: IdentifierType;
}
/** @oneof */
export interface ListActivationLogsRequestIdentifierOneOf {
    /** Look up activations by automation id */
    automationIdInfo?: AutomationIdInfo;
    /** Look up activations by preinstalled identifier */
    preinstalledIdentifierInfo?: PreinstalledIdentifierInfo;
}
export interface CursorPaging {
    /**
     * Maximum number of items to return in the results.
     * @max 500
     */
    limit?: number | null;
    /**
     * Pointer to the next or previous page in the list of results.
     *
     * Pass the relevant cursor token from the `pagingMetadata` object in the previous call's response.
     * Not relevant for the first request.
     * @maxLength 16000
     */
    cursor?: string | null;
}
/** Type of identifier used to look up activation logs */
export declare enum IdentifierType {
    UNKNOWN_TYPE = "UNKNOWN_TYPE"
}
export interface AutomationIdInfo {
    /**
     * Automation ID
     * @format GUID
     */
    automationId?: string;
}
export interface PreinstalledIdentifierInfo {
    /**
     * ID of the app that defines the preinstalled automation.
     * @format GUID
     */
    appId?: string;
    /**
     * Application component ID.
     * @format GUID
     */
    componentId?: string;
}
export interface ListActivationLogsResponse {
    /** List of activation logs */
    activationLogs?: ActivationLog[];
    /** Paging metadata */
    pagingMetadata?: CursorPagingMetadata;
}
export interface CursorPagingMetadata {
    /** Number of items returned in the response. */
    count?: number | null;
    /** Cursor string that point to the next page */
    cursors?: Cursors;
    /**
     * Whether there are more pages to retrieve following the current page.
     *
     * + `true`: Another page of results can be retrieved.
     * + `false`: This is the last page.
     */
    hasNext?: boolean | null;
}
export interface Cursors {
    /**
     * Cursor string pointing to the next page in the list of results.
     * @maxLength 16000
     */
    next?: string | null;
}
export interface SearchActivationLogsByPayloadPiiValueRequest extends SearchActivationLogsByPayloadPiiValueRequestFilterOptionOneOf {
    /** Filter activations by value and automation id */
    automationIdInfo?: AutomationIdInfo;
    /** Filter activations by value and preinstalled */
    preinstalledIdentifierInfo?: PreinstalledIdentifierInfo;
    /**
     * Value to search in the payload
     * @minLength 1
     * @maxLength 50
     */
    value: string;
    /** Paging */
    cursorPaging?: CursorPaging;
    /** Should return payload in the response */
    includePayload?: boolean | null;
    /** Filter by */
    filterBy?: FilterBy;
    /** From created date */
    fromCreatedDate?: Date | null;
    /** To created date */
    toCreatedDate?: Date | null;
}
/** @oneof */
export interface SearchActivationLogsByPayloadPiiValueRequestFilterOptionOneOf {
    /** Filter activations by value and automation id */
    automationIdInfo?: AutomationIdInfo;
    /** Filter activations by value and preinstalled */
    preinstalledIdentifierInfo?: PreinstalledIdentifierInfo;
}
/** FilterBy */
export declare enum FilterBy {
    UNKNOWN_TYPE = "UNKNOWN_TYPE"
}
export interface SearchActivationLogsByPayloadPiiValueResponse {
    /** List of activation logs */
    activationLogs?: ActivationLog[];
    /** Paging metadata */
    pagingMetadata?: CursorPagingMetadata;
}
export interface MessageEnvelope {
    /**
     * App instance ID.
     * @format GUID
     */
    instanceId?: string | null;
    /**
     * Event type.
     * @maxLength 150
     */
    eventType?: string;
    /** The identification type and identity data. */
    identity?: IdentificationData;
    /** Stringify payload. */
    data?: string;
}
export interface IdentificationData extends IdentificationDataIdOneOf {
    /**
     * ID of a site visitor that has not logged in to the site.
     * @format GUID
     */
    anonymousVisitorId?: string;
    /**
     * ID of a site visitor that has logged in to the site.
     * @format GUID
     */
    memberId?: string;
    /**
     * ID of a Wix user (site owner, contributor, etc.).
     * @format GUID
     */
    wixUserId?: string;
    /**
     * ID of an app.
     * @format GUID
     */
    appId?: string;
    /** @readonly */
    identityType?: WebhookIdentityType;
}
/** @oneof */
export interface IdentificationDataIdOneOf {
    /**
     * ID of a site visitor that has not logged in to the site.
     * @format GUID
     */
    anonymousVisitorId?: string;
    /**
     * ID of a site visitor that has logged in to the site.
     * @format GUID
     */
    memberId?: string;
    /**
     * ID of a Wix user (site owner, contributor, etc.).
     * @format GUID
     */
    wixUserId?: string;
    /**
     * ID of an app.
     * @format GUID
     */
    appId?: string;
}
export declare enum WebhookIdentityType {
    UNKNOWN = "UNKNOWN",
    ANONYMOUS_VISITOR = "ANONYMOUS_VISITOR",
    MEMBER = "MEMBER",
    WIX_USER = "WIX_USER",
    APP = "APP"
}
interface InitiatedStatusInfoNonNullableFields {
    target: Target;
}
interface ScheduledStatusInfoNonNullableFields {
    scheduleId: string;
}
interface CancelledStatusInfoNonNullableFields {
    reason: CancellationReason;
}
interface FailedStatusInfoNonNullableFields {
    errorDescription: string;
    errorReason: ErrorReason;
}
interface SkippedStatusInfoNonNullableFields {
    reason: SkipReason;
}
interface WarningNonNullableFields {
    errorDescription: string;
    reason: WarningReason;
}
export interface ActivationLogNonNullableFields {
    _id: string;
    automationId: string;
    automationRevision: string;
    status: Status;
    initiatedInfo?: InitiatedStatusInfoNonNullableFields;
    scheduledInfo?: ScheduledStatusInfoNonNullableFields;
    cancelledInfo?: CancelledStatusInfoNonNullableFields;
    failedInfo?: FailedStatusInfoNonNullableFields;
    skippedInfo?: SkippedStatusInfoNonNullableFields;
    warnings: WarningNonNullableFields[];
}
export interface GetActivationLogResponseNonNullableFields {
    activationLog?: ActivationLogNonNullableFields;
}
export interface ListActivationLogsResponseNonNullableFields {
    activationLogs: ActivationLogNonNullableFields[];
}
export interface SearchActivationLogsByPayloadPiiValueResponseNonNullableFields {
    activationLogs: ActivationLogNonNullableFields[];
}
/**
 * Get activation log by ID
 * @param activationId - Activation log ID
 * @public
 * @documentationMaturity preview
 * @requiredField activationId
 * @permissionId AUTOMATIONS.ACTIVATION_LOG_READ
 * @permissionScope Set Up Automations
 * @permissionScopeId SCOPE.CRM.SETUP-AUTOMATIONS
 * @applicableIdentity APP
 * @returns Activation log
 * @fqn wix.automations.activation_logs.v1.ActivationLogsService.GetActivationLog
 */
export declare function getActivationLog(activationId: string): Promise<ActivationLog & ActivationLogNonNullableFields>;
/**
 * List activation logs
 * @public
 * @documentationMaturity preview
 * @permissionId AUTOMATIONS.ACTIVATION_LOG_READ
 * @permissionScope Set Up Automations
 * @permissionScopeId SCOPE.CRM.SETUP-AUTOMATIONS
 * @applicableIdentity APP
 * @fqn wix.automations.activation_logs.v1.ActivationLogsService.ListActivationLogs
 */
export declare function listActivationLogs(options?: ListActivationLogsOptions): Promise<ListActivationLogsResponse & ListActivationLogsResponseNonNullableFields>;
export interface ListActivationLogsOptions extends ListActivationLogsOptionsIdentifierOneOf {
    /** From created date, If not specified, defaults to 30 days before the current time. */
    fromCreatedDate?: Date | null;
    /** To created date, If not specified, defaults to current time. */
    toCreatedDate?: Date | null;
    /** Paging */
    cursorPaging?: CursorPaging;
    /** Should return payload in the response */
    includePayload?: boolean | null;
    /** identifier type for the activations to list */
    identifierType?: IdentifierType;
    /** Look up activations by automation id */
    automationIdInfo?: AutomationIdInfo;
    /** Look up activations by preinstalled identifier */
    preinstalledIdentifierInfo?: PreinstalledIdentifierInfo;
}
/** @oneof */
export interface ListActivationLogsOptionsIdentifierOneOf {
    /** Look up activations by automation id */
    automationIdInfo?: AutomationIdInfo;
    /** Look up activations by preinstalled identifier */
    preinstalledIdentifierInfo?: PreinstalledIdentifierInfo;
}
/**
 * Search activation logs by payload pii value
 * Entire field value match is supported
 * Supported are emails, phones and guids
 * @param value - Value to search in the payload
 * @public
 * @documentationMaturity preview
 * @requiredField value
 * @permissionId AUTOMATIONS.ACTIVATION_LOG_READ
 * @permissionScope Set Up Automations
 * @permissionScopeId SCOPE.CRM.SETUP-AUTOMATIONS
 * @applicableIdentity APP
 * @fqn wix.automations.activation_logs.v1.ActivationLogsService.SearchActivationLogsByPayloadPiiValue
 */
export declare function searchActivationLogsByPayloadPiiValue(value: string, options?: SearchActivationLogsByPayloadPiiValueOptions): Promise<SearchActivationLogsByPayloadPiiValueResponse & SearchActivationLogsByPayloadPiiValueResponseNonNullableFields>;
export interface SearchActivationLogsByPayloadPiiValueOptions extends SearchActivationLogsByPayloadPiiValueOptionsFilterOptionOneOf {
    /** Paging */
    cursorPaging?: CursorPaging;
    /** Should return payload in the response */
    includePayload?: boolean | null;
    /** Filter by */
    filterBy?: FilterBy;
    /** Filter activations by value and automation id */
    automationIdInfo?: AutomationIdInfo;
    /** Filter activations by value and preinstalled */
    preinstalledIdentifierInfo?: PreinstalledIdentifierInfo;
    /** From created date */
    fromCreatedDate?: Date | null;
    /** To created date */
    toCreatedDate?: Date | null;
}
/** @oneof */
export interface SearchActivationLogsByPayloadPiiValueOptionsFilterOptionOneOf {
    /** Filter activations by value and automation id */
    automationIdInfo?: AutomationIdInfo;
    /** Filter activations by value and preinstalled */
    preinstalledIdentifierInfo?: PreinstalledIdentifierInfo;
}
export {};
